ArenaSpec = DongleStub("Dongle-Beta0"):New( "ArenaSpec" );

local enemies = {};

function ArenaSpec:Initialize()
	if( not ArenaSpec_NoDataID ) then
		ArenaSpec_NoDataID = 0;
	end
	
	if( not ArenaSpec_NoData or ArenaSpec_NoDataID == ArenaSpec_DataID ) then
		ArenaSpec_NoData = {};
	end
	
	self:RegisterEvent( "UPDATE_BATTLEFIELD_STATUS" );
	self:RegisterEvent( "UPDATE_MOUSEOVER_UNIT" );
	self:RegisterEvent( "CHAT_MSG_ADDON" );
end

function ArenaSpec:GetSpec( name, server )
	name = name .. "-" .. server;
	if( ArenaSpec_Data[ name ] ) then
		return " [" .. ArenaSpec_Data[ name ][1] .. "/" .. ArenaSpec_Data[ name ][2] .. "/" .. ArenaSpec_Data[ name ][3] .. "]";
	end
	
	return "";
end

function ArenaSpec:GetTalents( name, server )
	name = name .. "-" .. server;
	
	if( ArenaSpec_Data[ name ] ) then
		return ArenaSpec_Data[ name ][1], ArenaSpec_Data[ name ][2], ArenaSpec_Data[ name ][3];
	end
	
	return 0, 0, 0;
end

function ArenaSpec:BGMessage( msg )
	if( GetNumRaidMembers() > 0 or GetNumPartyMembers() > 0 ) then
		SendChatMessage( msg, "BATTLEGROUND" );
	end
end

function ArenaSpec:CHAT_MSG_ADDON( event, prefix, msg, type, author )
	if( prefix == "SSPVP" and not IsAddOnLoaded( "SSPVP" ) ) then
		local _, _, dataType, data = string.find( msg, "([^:]+)%:(.+)" );
		
		if( dataType and data and dataType == "ENEMY" ) then
			local name, server, race, classToken, guild = string.split( ",", data );
			
			for _, enemy in pairs( enemies ) do
				if( enemy.name == name ) then
					return;
				end
			end

			table.insert( enemies, { name = name, server = server, race = race, classToken = classToken, guild = guild } );
		end
	end
end

-- Why identify as SSPVP? 
-- Because i'm lazy and rather use the format I already have for syncing
function ArenaSpec:CommMessage( msg )
	SendAddonMessage( "SSPVP", msg, "BATTLEGROUND" );
end

local battlefieldID = -1;
function ArenaSpec:UPDATE_BATTLEFIELD_STATUS()
	for i=1, MAX_BATTLEFIELD_QUEUES do
		local status = GetBattlefieldStatus( i );
		
		if( status == "active" and i ~= battlefieldID ) then
			battlefieldID = i;
		elseif( status ~= "active" and i == battlefieldID ) then
			battlefieldID = -1;
			enemies = {};
		end
	end	
end

function ArenaSpec:UPDATE_MOUSEOVER_UNIT()
	if( ( IsActiveBattlefieldArena() ) and UnitIsPlayer( "mouseover" ) and UnitIsEnemy( "mouseover", "player" ) and UnitIsPVP( "mouseover" ) ) then
		local name, server = UnitName( "mouseover" );
		server = ( server or GetRealmName() );
		
		if( not ArenaSpec_Data[ name .. "-" .. server ] ) then
			for _, noSpec in pairs( ArenaSpec_NoData ) do
				if( noSpec == name .. "-" .. server ) then
					return;
				end
			end
			
			ArenaSpec_NoDataID = floor( GetTime() );
			table.insert( ArenaSpec_NoData, name .. "-" .. server );
		end
		
		-- SSPVP 3 has built in support for this
		if( IsAddOnLoaded( "SSPVP" ) ) then
			return;
		end
		
		for _, enemy in pairs( enemies ) do
			if( enemy.name == name ) then
				return;
			end
		end
		
		local race = UnitRace( "mouseover" );
		local class, classToken = UnitClass( "mouseover" );
		local guild = GetGuildInfo( "mouseover" );

		table.insert( enemies, { name = name, server = server, race = race, classToken = classToken, guild = guild } );
		
		-- Print out info message
		if( guild ) then
			ArenaSpec:BGMessage( string.format( "%s / %s / %s / %s / %s", name, class, race, guild, server, spec ) );
			ArenaSpec:CommMessage( "ENEMY:" .. name .. "," .. server .. "," .. race .. "," .. classToken .. "," .. guild );
		else
			ArenaSpec:BGMessage( string.format( "%s / %s / %s / %s", name, class, race, server, spec ) );				
			ArenaSpec:CommMessage( "ENEMY:" .. name .. "," .. server .. "," .. race .. "," .. classToken );
		end
	end
end